==> mzanalytics_mybmw-0.2.2.tar.gz: lib/mzanalytics_mybmw.dart <==
import 'dart:async';
import 'package:built_collection/built_collection.dart';
import 'package:flutter/widgets.dart';
import 'package:flutter/services.dart';
import 'dart:io';
import 'package:mzanalytics_mybmw/mzanalytics_ios.dart';
import 'package:mzanalytics_mybmw/mzanalytics_android.dart';

class MzanalyticsMybmw {
  static Future<void> appid(String aid) async {
    try {
      if (Platform.isIOS) {
        Mzanalytics_ios.appid(aid);
      } else if (Platform.isAndroid) {
        Mzanalytics_android.initEvent();
      } else if (Platform.isMacOS) {}
    } on PlatformException {}
  }

  static Future<void> trackPageView(Map parameter) async {
    try {
      if (Platform.isIOS) {
        Mzanalytics_ios.trackPageView(parameter);
      } else if (Platform.isAndroid) {
        Mzanalytics_android.trackPageView(parameter);
      }
    } on PlatformException {}
  }

  static Future<void> trackEvent(Map parameter) async {
    try {
      if (Platform.isIOS) {
        Mzanalytics_ios.trackEvent(parameter);
      } else if (Platform.isAndroid) {
        Mzanalytics_android.trackEvent(parameter);
      }
    } on PlatformException {}
  }

  static Future<void> trackSiteCustomEvent(Map parameter) async {
    try {
      if (Platform.isIOS) {
        Mzanalytics_ios.trackSiteCustomEvent(parameter);
      } else if (Platform.isAndroid) {
        Mzanalytics_android.trackSiteCustomEvent(parameter);
      }
    } on PlatformException {}
  }

  static Future<void> trackPulse() async {
    try {
      if (Platform.isIOS) {
        Mzanalytics_ios.trackPulse();
      } else if (Platform.isAndroid) {
        Mzanalytics_android.trackPulse();
      }
    } on PlatformException {}
  }

  static Future<String> getCid() async {
    try {
      if (Platform.isIOS) {
        final String cid = await Mzanalytics_ios.getCid();
        return cid;
      } else if (Platform.isAndroid) {
        final String cid = await Mzanalytics_android.getCid();
        return cid;
      }
    } on PlatformException {}
  }

  static Future<String> getOaid() async {
    try {
      if (Platform.isAndroid) {
        final String oaid = await Mzanalytics_android.getOaid();
        return oaid;
      }
    } on PlatformException {}
  }

  static Future<void> onDeepLinkReceived(String url) async {
    try {
      if (Platform.isIOS) {
        Mzanalytics_ios.handleOpenURL(url);
      } else if (Platform.isAndroid) {
        Mzanalytics_android.handleOpenURL(url);
      }
    } on PlatformException {}
  }
  /** 自定义cd和cm统一对外方法 */

  static Future<Map> getCdAndCm() async {
    try {
      if (Platform.isAndroid) {
        return Mzanalytics_android.getCdAndCm();
      } else if (Platform.isIOS) {
        return Mzanalytics_ios.getCdAndCm();
      }
    } on FileSystemException {
      return null;
    }
  }

  static Future<void> setCd(String cd_key, String cd_value) async {
    try {
      if (Platform.isAndroid) {
        Mzanalytics_android.setCd(cd_key, cd_value);
      } else if (Platform.isIOS) {
        Mzanalytics_ios.setCd(cd_key, cd_value);
      }
    } on FileSystemException {}
  }

  static Future<void> setCm(String cm_key, String cm_value) async {
    try {
      if (Platform.isAndroid) {
        Mzanalytics_android.setCm(cm_key, cm_value);
      } else if (Platform.isIOS) {
        Mzanalytics_ios.setCm(cm_key, cm_value);
      }
    } on FileSystemException {}
  }

  static Future<void> deleteCd(String cd_key) async {
    try {
      if (Platform.isAndroid) {
        Mzanalytics_android.deleteCd(cd_key);
      } else if (Platform.isIOS) {
        Mzanalytics_ios.deleteCd(cd_key);
      }
    } on FileSystemException {}
  }

  static Future<void> deleteCm(String cm_key) async {
    try {
      if (Platform.isAndroid) {
        Mzanalytics_android.deleteCm(cm_key);
      } else if (Platform.isIOS) {
        Mzanalytics_ios.deleteCm(cm_key);
      }
    } on FileSystemException {}
  }

  static Future<bool> isAutoTrackpage() async {
    try {
      if (Platform.isAndroid) {
        return Mzanalytics_android.isAutoTrackpage();
      } else if (Platform.isIOS) {
        return Mzanalytics_ios.isAutoTrackpage();
      }
    } on FileSystemException {}
  }

  static Future<List> getBlackList() async {
    try {
      if (Platform.isAndroid) {
        return Mzanalytics_android.getBlackList();
      } else if (Platform.isIOS) {
        return Mzanalytics_ios.getBlackList();
      }
    } on FileSystemException {}
  }
}

class MZNavigationHistoryObserver extends NavigatorObserver {
  /// A list of all the past routes
  List<Route<dynamic>> _history = <Route<dynamic>>[];

  /// Gets a clone of the navigation history as an immutable list.
  get history => BuiltList<Route<dynamic>>.from(_history);

  /// Gets the top route in the navigation stack.
  get top => _history.last;

  /// A list of all routes that were popped to reach the current.
  List<Route<dynamic>> _poppedRoutes = <Route<dynamic>>[];

  /// Gets a clone of the popped routes as an immutable list.
  get poppedRoutes => BuiltList<Route<dynamic>>.from(_poppedRoutes);

  /// Gets the next route in the navigation history, which is the most recently popped route.
  get next => _poppedRoutes.last;

  /// A stream that broadcasts whenever the navigation history changes.
  StreamController _historyChangeStreamController =
      StreamController.broadcast();

  /// Accessor to the history change stream.
  get historyChangeStream => _historyChangeStreamController.stream;

  static final MZNavigationHistoryObserver _singleton =
      MZNavigationHistoryObserver._internal();
  MZNavigationHistoryObserver._internal();
  factory MZNavigationHistoryObserver() {
    return _singleton;
  }

  @override
  void didPop(Route<dynamic> route, Route<dynamic> previousRoute) {
    _poppedRoutes.add(_history.last);
    _history.removeLast();
    _historyChangeStreamController.add(HistoryChange(
      action: NavigationStackAction.pop,
      newRoute: route,
      oldRoute: previousRoute,
    ));
  }

  @override
  void didPush(Route<dynamic> route, Route<dynamic> previousRoute) {
    _history.add(route);
    _poppedRoutes.remove(route);
    try {
      MzanalyticsMybmw.isAutoTrackpage().then((bool isAutoTrackpage) {
        MzanalyticsMybmw.getBlackList().then((List blackpvList) {
          if (route.settings.name != null &&
              route.settings.name != '/' &&
              isAutoTrackpage &&
              !blackpvList.contains(route.settings.name)) {
            print('sending...');
            Map selfparams = new Map();
            MzanalyticsMybmw.getCdAndCm().then((Map value) {
              print("读取的自定义事件:" + value.toString());
              if (value != null) {
                selfparams = value;
              }
              //{'pageTitle': route.settings.name;CustomDimMetrics:字典}; {'pageTitle': route.settings.name;字典}

              selfparams['dt'] = route.settings.name;
              print('准备发送的数据：' + selfparams.toString());
              MzanalyticsMybmw.trackPageView(selfparams);
            });
          }
        });
      });
    } on PlatformException {}
    _historyChangeStreamController.add(HistoryChange(
      action: NavigationStackAction.push,
      newRoute: route,
      oldRoute: previousRoute,
    ));
  }

  @override
  void didRemove(Route<dynamic> route, Route<dynamic> previousRoute) {
    _history.remove(route);
    _historyChangeStreamController.add(HistoryChange(
      action: NavigationStackAction.remove,
      newRoute: route,
      oldRoute: previousRoute,
    ));
  }

  @override
  void didReplace({Route<dynamic> newRoute, Route<dynamic> oldRoute}) {
    int oldRouteIndex = _history.indexOf(oldRoute);
    _history.replaceRange(oldRouteIndex, oldRouteIndex + 1, [newRoute]);
    _historyChangeStreamController.add(HistoryChange(
      action: NavigationStackAction.replace,
      newRoute: newRoute,
      oldRoute: oldRoute,
    ));
  }
}

/// A class that contains all data that needs to be broadcasted through the history change stream.
class HistoryChange {
  HistoryChange({this.action, this.newRoute, this.oldRoute});

  final NavigationStackAction action;
  final Route<dynamic> newRoute;
  final Route<dynamic> oldRoute;
}

enum NavigationStackAction { push, pop, remove, replace }

==> mzanalytics_mybmw-0.2.3.tar.gz: lib/mzanalytics_mybmw.dart <==
import 'dart:async';
import 'package:built_collection/built_collection.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/widgets.dart';
import 'package:flutter/services.dart';
import 'dart:io';
import 'package:mzanalytics_mybmw/mzanalytics_ios.dart';
import 'package:mzanalytics_mybmw/mzanalytics_android.dart';

class mzanalyticsMybmw {
  ///初始化SDK
  static Future<void> appid(String aid) async {
    try {
      if (Platform.isIOS) {
        mzanalytics_ios.appid(aid);
      } else if (Platform.isAndroid) {
        mzanalytics_android.initEvent();
      } else if (Platform.isMacOS) {}
    } on PlatformException {}
  }

  ///记录页面
  static Future<void> trackPageView(Map parameter) async {
    try {
      if (Platform.isIOS) {
        mzanalytics_ios.trackPageView(parameter);
      } else if (Platform.isAndroid) {
        mzanalytics_android.trackPageView(parameter);
      }
    } on PlatformException {}
  }

  ///基础事件
  static Future<void> trackEvent(Map parameter) async {
    try {
      if (Platform.isIOS) {
        mzanalytics_ios.trackEvent(parameter);
      } else if (Platform.isAndroid) {
        mzanalytics_android.trackEvent(parameter);
      }
    } on PlatformException {}
  }

  ///自定义方法
  static Future<void> trackSiteCustomEvent(Map parameter) async {
    try {
      if (Platform.isIOS) {
        mzanalytics_ios.trackSiteCustomEvent(parameter);
      } else if (Platform.isAndroid) {
        mzanalytics_android.trackSiteCustomEvent(parameter);
      }
    } on PlatformException {}
  }

  ///心跳事件
  static Future<void> trackPulse() async {
    try {
      if (Platform.isIOS) {
        mzanalytics_ios.trackPulse();
      } else if (Platform.isAndroid) {
        mzanalytics_android.trackPulse();
      }
    } on PlatformException {}
  }

  ///获取cid
  static Future<String> getCid() async {
    try {
      if (Platform.isIOS) {
        final String cid = await mzanalytics_ios.getCid();
        return cid;
      } else if (Platform.isAndroid) {
        final String cid = await mzanalytics_android.getCid();
        return cid;
      }
    } on PlatformException {}
  }

  ///获取oaid
  static Future<String> getOaid() async {
    try {
      if (Platform.isAndroid) {
        final String oaid = await mzanalytics_android.getOaid();
        return oaid;
      }
    } on PlatformException {}
  }

  ///deeplink
  static Future<void> onDeepLinkReceived(String url) async {
    try {
      if (Platform.isIOS) {
        mzanalytics_ios.handleOpenURL(url);
      } else if (Platform.isAndroid) {
        mzanalytics_android.handleOpenURL(url);
      }
    } on PlatformException {}
  }
  /** 自定义cd和cm统一对外方法 */

  static Future<Map> getCdAndCm() async {
    try {
      if (Platform.isAndroid) {
        return mzanalytics_android.getCdAndCm();
      } else if (Platform.isIOS) {
        return mzanalytics_ios.getCdAndCm();
      }
    } on FileSystemException {
      return null;
    }
  }

  ///设置全局cd
  static Future<void> setCd(String cd_key, String cd_value) async {
    try {
      if (Platform.isAndroid) {
        mzanalytics_android.setCd(cd_key, cd_value);
      } else if (Platform.isIOS) {
        mzanalytics_ios.setCd(cd_key, cd_value);
      }
    } on FileSystemException {}
  }

  ///设置全局cm
  static Future<void> setCm(String cm_key, String cm_value) async {
    try {
      if (Platform.isAndroid) {
        mzanalytics_android.setCm(cm_key, cm_value);
      } else if (Platform.isIOS) {
        mzanalytics_ios.setCm(cm_key, cm_value);
      }
    } on FileSystemException {}
  }

  ///删除全局cd
  static Future<void> deleteCd(String cd_key) async {
    try {
      if (Platform.isAndroid) {
        mzanalytics_android.deleteCd(cd_key);
      } else if (Platform.isIOS) {
        mzanalytics_ios.deleteCd(cd_key);
      }
    } on FileSystemException {}
  }

  ///删除全局cm
  static Future<void> deleteCm(String cm_key) async {
    try {
      if (Platform.isAndroid) {
        mzanalytics_android.deleteCm(cm_key);
      } else if (Platform.isIOS) {
        mzanalytics_ios.deleteCm(cm_key);
      }
    } on FileSystemException {}
  }

  ///isAutoTrackpage
  static Future<bool> isAutoTrackpage() async {
    try {
      if (Platform.isAndroid) {
        return mzanalytics_android.isAutoTrackpage();
      } else if (Platform.isIOS) {
        return mzanalytics_ios.isAutoTrackpage();
      }
    } on FileSystemException {}
  }

  ///getBlackList
  static Future<List> getBlackList() async {
    try {
      if (Platform.isAndroid) {
        return mzanalytics_android.getBlackList();
      } else if (Platform.isIOS) {
        return mzanalytics_ios.getBlackList();
      }
    } on FileSystemException {
      if (kIsWeb) {}
    }
  }
}

///（可选）导航路由观察者方法
class mzNavigationHistoryObserver extends NavigatorObserver {
  /// A list of all the past routes
  List<Route<dynamic>> _history = <Route<dynamic>>[];

  /// Gets a clone of the navigation history as an immutable list.
  get history => BuiltList<Route<dynamic>>.from(_history);

  /// Gets the top route in the navigation stack.
  get top => _history.last;

  /// A list of all routes that were popped to reach the current.
  List<Route<dynamic>> _poppedRoutes = <Route<dynamic>>[];

  /// Gets a clone of the popped routes as an immutable list.
  get poppedRoutes => BuiltList<Route<dynamic>>.from(_poppedRoutes);

  /// Gets the next route in the navigation history, which is the most recently popped route.
  get next => _poppedRoutes.last;

  /// A stream that broadcasts whenever the navigation history changes.
  StreamController _historyChangeStreamController =
      StreamController.broadcast();

  /// Accessor to the history change stream.
  get historyChangeStream => _historyChangeStreamController.stream;

  static final mzNavigationHistoryObserver _singleton =
      mzNavigationHistoryObserver._internal();
  mzNavigationHistoryObserver._internal();
  factory mzNavigationHistoryObserver() {
    return _singleton;
  }

  @override
  void didPop(Route<dynamic> route, Route<dynamic> previousRoute) {
    _poppedRoutes.add(_history.last);
    _history.removeLast();
    _historyChangeStreamController.add(HistoryChange(
      action: NavigationStackAction.pop,
      newRoute: route,
      oldRoute: previousRoute,
    ));
  }

  ///打开页面
  @override
  void didPush(Route<dynamic> route, Route<dynamic> previousRoute) {
    _history.add(route);
    _poppedRoutes.remove(route);
    try {
      mzanalyticsMybmw.isAutoTrackpage().then((bool isAutoTrackpage) {
        mzanalyticsMybmw.getBlackList().then((List blackpvList) {
          if (route.settings.name != null &&
              route.settings.name != '/' &&
              isAutoTrackpage &&
              !blackpvList.contains(route.settings.name)) {
            print('sending...');
            Map selfparams = new Map();
            mzanalyticsMybmw.getCdAndCm().then((Map value) {
              print("读取的自定义事件:" + value.toString());
              if (value != null) {
                selfparams = value;
              }
              //{'pageTitle': route.settings.name;CustomDimMetrics:字典}; {'pageTitle': route.settings.name;字典}

              selfparams['dt'] = route.settings.name;
              print('准备发送的数据：' + selfparams.toString());
              mzanalyticsMybmw.trackPageView(selfparams);
            });
          }
        });
      });
    } on PlatformException {}
    _historyChangeStreamController.add(HistoryChange(
      action: NavigationStackAction.push,
      newRoute: route,
      oldRoute: previousRoute,
    ));
  }

  @override
  void didRemove(Route<dynamic> route, Route<dynamic> previousRoute) {
    _history.remove(route);
    _historyChangeStreamController.add(HistoryChange(
      action: NavigationStackAction.remove,
      newRoute: route,
      oldRoute: previousRoute,
    ));
  }

  @override
  void didReplace({Route<dynamic> newRoute, Route<dynamic> oldRoute}) {
    int oldRouteIndex = _history.indexOf(oldRoute);
    _history.replaceRange(oldRouteIndex, oldRouteIndex + 1, [newRoute]);
    _historyChangeStreamController.add(HistoryChange(
      action: NavigationStackAction.replace,
      newRoute: newRoute,
      oldRoute: oldRoute,
    ));
  }
}

/// A class that contains all data that needs to be broadcasted through the history change stream.
class HistoryChange {
  HistoryChange({this.action, this.newRoute, this.oldRoute});

  final NavigationStackAction action;
  final Route<dynamic> newRoute;
  final Route<dynamic> oldRoute;
}

enum NavigationStackAction { push, pop, remove, replace }
